//
//  it_device.h
//  AirClick
//
//  Created by Casey on 7/27/04.
//  Copyright 2004 Griffin Technology, Inc.. All rights reserved.
//

#import <IOKit/hid/IOHIDLib.h>

typedef enum {
    eButtonID_Huh = 0x00,
    eButtonID_PlayPause = 0x01,
    eButtonID_VolumeUp = 0x02,
    eButtonID_VolumeDown = 0x04,
    eButtonID_NextTrack = 0x08,
    eButtonID_PrevTrack = 0x10,
} eButtonID;

extern NSString		*gRemoteEventNotification;
extern NSString		*gConnectionNotification;

@interface it_deviceEvent : NSObject
{
	eButtonID	mButtonID;
	BOOL		mButtonPressed;
}

+ (id)				event: (BOOL) inButtonState
						withID: (eButtonID) inButtonID;
- (id)				initWithState: (BOOL) inButtonState
						withID: (eButtonID) inButtonID;
						
- (BOOL)			buttonPressed;
- (eButtonID)		buttonID;

@end

@interface it_device : NSObject
{
	io_service_t			mUSBDevice;
	io_object_t				mDevNotification;
	io_iterator_t			mIteratorAdd;
	IOHIDDeviceInterface	**mHIDInterface;
	IOHIDQueueInterface		**mHIDQueue;
	IONotificationPortRef 	mNotifyPort;
	CFRunLoopSourceRef		mQueueRunLoopSource;
	
	BOOL					mDeviceConnected;
	UInt32					mButtonStates;
	UInt32					mModifiers;
}

- (IOReturn)		start;
- (UInt16)			getIDWithDictionary: (CFMutableDictionaryRef) properties
						andKey: (const char *) IDkey;
- (void)			deviceConnected: (io_service_t) inDevice
						withInterface: (IOHIDDeviceInterface **) inInterface
						andProperties: (NSDictionary *) inProperties;
- (void)			deviceDisconnected: (io_service_t)inService;
- (IOReturn)		testAddedDevice: (io_service_t) inDevice;
- (IOReturn)		queueDevice: (NSArray *) inElements
						withCallback: (IOHIDCallbackFunction) inCallback;
- (void)			processQueueEvents;

- (BOOL)			connected;
- (UInt8)			modifiers;
- (UInt8)			buttonMap;

@end
